@@ -5,15 +5,23 @@ from __future__ import absolute_import
 # import apis into api package
 from pulpcore.client.pulpcore.api.access_policies_api import AccessPoliciesApi
 from pulpcore.client.pulpcore.api.artifacts_api import ArtifactsApi
-from pulpcore.client.pulpcore.api.exporters_core_exports_api import ExportersCoreExportsApi
+from pulpcore.client.pulpcore.api.content_api import ContentApi
+from pulpcore.client.pulpcore.api.contentguards_api import ContentguardsApi
 from pulpcore.client.pulpcore.api.exporters_pulp_api import ExportersPulpApi
+from pulpcore.client.pulpcore.api.exporters_pulp_exports_api import ExportersPulpExportsApi
 from pulpcore.client.pulpcore.api.groups_api import GroupsApi
 from pulpcore.client.pulpcore.api.groups_model_permissions_api import GroupsModelPermissionsApi
 from pulpcore.client.pulpcore.api.groups_object_permissions_api import GroupsObjectPermissionsApi
 from pulpcore.client.pulpcore.api.groups_users_api import GroupsUsersApi
-from pulpcore.client.pulpcore.api.importers_core_imports_api import ImportersCoreImportsApi
 from pulpcore.client.pulpcore.api.importers_pulp_api import ImportersPulpApi
+from pulpcore.client.pulpcore.api.importers_pulp_import_check_api import ImportersPulpImportCheckApi
+from pulpcore.client.pulpcore.api.importers_pulp_imports_api import ImportersPulpImportsApi
 from pulpcore.client.pulpcore.api.orphans_api import OrphansApi
+from pulpcore.client.pulpcore.api.orphans_cleanup_api import OrphansCleanupApi
+from pulpcore.client.pulpcore.api.publications_api import PublicationsApi
+from pulpcore.client.pulpcore.api.repair_api import RepairApi
+from pulpcore.client.pulpcore.api.repositories_api import RepositoriesApi
+from pulpcore.client.pulpcore.api.repository_versions_api import RepositoryVersionsApi
 from pulpcore.client.pulpcore.api.signing_services_api import SigningServicesApi
 from pulpcore.client.pulpcore.api.status_api import StatusApi
 from pulpcore.client.pulpcore.api.task_groups_api import TaskGroupsApi
